{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2015-2022 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{{ webpack['theme.js']}}
{{ webpack['base-theme-rdm.js']}}
{{ webpack['i18n_app.js']}}
